Documentation
¶
Overview ¶
Package picker provides the bubbletea TUI for fuzzy-filtering and previewing sessions.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Model ¶
type Model struct {
// contains filtered or unexported fields
}
Model is the bubbletea model for the interactive session picker.
type RefreshMsg ¶ added in v0.3.2
type RefreshMsg struct{ Paths []string }
RefreshMsg is sent by the watcher when one or more JSONL files have changed.
Click to show internal directories.
Click to hide internal directories.